==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QWhatsThis_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(whatsthis)
#include <QtWidgets/qwhatsthis.h>
#endif //QT_CONFIG(whatsthis)
#include <QtCore/QVariant>
#include <QtCore/qpoint.h>
#include <QtWidgets/qwidget.h>
#include <QtWidgets/qaction.h>
#include <QtCore/qobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(whatsthis)


void deleter_QWhatsThis(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWhatsThis")
    QWhatsThis *_ptr = reinterpret_cast<QWhatsThis *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(whatsthis)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWhatsThis::createAction(QObject*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_createAction_1native_1QObject_1ptr__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID parent0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::createAction(QObject*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        QObject* __qt_parent0 = QtJambiAPI::objectFromNativeId<QObject>(parent0);
        QtJambiAPI::checkThreadOnArgument(__jni_env, "parent", __qt_parent0);
        QAction* __qt_return_value = QWhatsThis::createAction(__qt_parent0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(parent0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWhatsThis::enterWhatsThisMode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_enterWhatsThisMode__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::enterWhatsThisMode()")
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        QWhatsThis::enterWhatsThisMode();
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThis::hideText()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_hideText__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::hideText()")
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        QWhatsThis::hideText();
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThis::inWhatsThisMode()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_inWhatsThisMode__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::inWhatsThisMode()")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        __java_return_value = QWhatsThis::inWhatsThisMode();
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWhatsThis::leaveWhatsThisMode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_leaveWhatsThisMode__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::leaveWhatsThisMode()")
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        QWhatsThis::leaveWhatsThisMode();
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThis::showText(QPoint,QString,QWidget*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_showText_1native_1cref_1QPoint_1cref_1QString_1QWidget_1ptr__JLjava_lang_String_2J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID pos0,
 jstring text1,
 QtJambiNativeID w2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::showText(QPoint,QString,QWidget*)")
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        QtJambiAPI::checkThreadUI(__jni_env, typeid(QWhatsThis));
        const QPoint& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(pos0);
        QString  __qt_text1 = qtjambi_cast<QString >(__jni_env, text1);
        QWidget* __qt_w2 = QtJambiAPI::objectFromNativeId<QWidget>(w2);
        QWhatsThis::showText(__qt_pos0, __qt_text1, __qt_w2);
#else
        Q_UNUSED(pos0)
        Q_UNUSED(text1)
        Q_UNUSED(w2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWhatsThis(){
    using namespace RegistryAPI;

#if QT_CONFIG(whatsthis)

    const std::type_info& typeId = registerObjectTypeInfo<QWhatsThis>("QWhatsThis", "io/qt/widgets/QWhatsThis");
// BEGIN: function table
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWhatsThis);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(whatsthis)

}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QWhatsThis_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(whatsthis)
#include <QtWidgets/qwhatsthis.h>
#endif //QT_CONFIG(whatsthis)
#include <QtCore/QVariant>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtWidgets/qwidget.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(whatsthis)


void deleter_QWhatsThis(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWhatsThis")
    QWhatsThis *_ptr = reinterpret_cast<QWhatsThis *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(whatsthis)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWhatsThis::createAction(QObject*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_createAction_1native_1QObject_1ptr__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID parent0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::createAction(QObject*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        QObject* __qt_parent0 = QtJambiAPI::objectFromNativeId<QObject>(parent0);
        QtJambiAPI::checkThreadOnArgument(__jni_env, "parent", __qt_parent0);
        QAction* __qt_return_value = QWhatsThis::createAction(__qt_parent0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(parent0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWhatsThis::enterWhatsThisMode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_enterWhatsThisMode__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::enterWhatsThisMode()")
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        QWhatsThis::enterWhatsThisMode();
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThis::hideText()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_hideText__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::hideText()")
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        QWhatsThis::hideText();
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThis::inWhatsThisMode()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_inWhatsThisMode__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::inWhatsThisMode()")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        __java_return_value = QWhatsThis::inWhatsThisMode();
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWhatsThis::leaveWhatsThisMode()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_leaveWhatsThisMode__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::leaveWhatsThisMode()")
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        QWhatsThis::leaveWhatsThisMode();
#else
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThis::showText(QPoint,QString,QWidget*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QWhatsThis_showText_1native_1cref_1QPoint_1cref_1QString_1QWidget_1ptr__JLjava_lang_String_2J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID pos0,
 jstring text1,
 QtJambiNativeID w2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThis::showText(QPoint,QString,QWidget*)")
    QTJAMBI_TRY {
#if QT_CONFIG(whatsthis)
        QtJambiAPI::checkThreadUI(__jni_env, typeid(QWhatsThis));
        const QPoint& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(pos0);
        QString  __qt_text1 = qtjambi_cast<QString>(__jni_env, text1);
        QWidget* __qt_w2 = QtJambiAPI::objectFromNativeId<QWidget>(w2);
        QWhatsThis::showText(__qt_pos0, __qt_text1, __qt_w2);
#else
        Q_UNUSED(pos0)
        Q_UNUSED(text1)
        Q_UNUSED(w2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(whatsthis)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWhatsThis(){
    using namespace RegistryAPI;

#if QT_CONFIG(whatsthis)

    const std::type_info& typeId = registerObjectTypeInfo<QWhatsThis>("QWhatsThis", "io/qt/widgets/QWhatsThis");
// BEGIN: function table
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWhatsThis);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(whatsthis)

}
